
import { queryEgressApi } from '@/services/op-admin/gateway/egress';
import { ProForm, ProFormSelect, ProFormText, ProFormTextArea, StepsForm } from '@ant-design/pro-components';
import { message } from 'antd';
import React, { useState } from 'react';

/**
 * @author bianlanzhou
 * @since 2024-09-24
 * @desc 基础信息页面
 */

/** BasicInfoStepFormPage属性 */
type BasicInfoStepFormPageProp = {
  formref: React.MutableRefObject<any>;
}
const BasicInfoStepFormPage: React.FC<BasicInfoStepFormPageProp> = (props) => {
  /** API列表 */
  const [apiList, setApiList] = useState([]);
  /** API类型 */
  const [currentApiType, setCurrentApiType] = useState<string>();
  /** API类型名称 */
  const [currentApiTypeName, setCurrentApiTypeName] = useState<string>();
  /** api类型枚举 */
  const apiTypeEnum = {
    'loan': '助贷API',
    'product': '产品API',
    'other': '三方API',
  }

  /** 处理API列表查询 */
  const handleEgreessApiRequest = () => {
    return queryEgressApi().then((resp) => {
      if (resp.success) {
        setApiList(resp.data)
        return resp.data;
      }
      return []
    }).catch((err) => {
      console.log(err)
      return []
    });
  }
  return (
    <StepsForm.StepForm<{
      name: string;
    }>
      name="base"
      title="基础信息"
      onFinish={async ({ }) => {
        return true;
      }}
      formRef={props.formref}
      style={{ minHeight: '50vh' }}
    >
      <ProForm.Group >
        <ProFormSelect
          width="md"
          name="apiId"
          label="所属API"
          placeholder="请选择所属API"
          request={handleEgreessApiRequest}
          fieldProps={
            {
              fieldNames: {
                label: 'apiName',
                value: 'id'
              }
            }
          }
          rules={[
            {
              required: true,
              message: '请选择所属API',
            },
          ]}
          onChange={(e: any) => {
            if (e) {
              apiList.forEach((item: any) => {
                if (item.id === e) {
                  setCurrentApiType(item.apiType);
                  setCurrentApiTypeName(apiTypeEnum[item.apiType as 'loan' || 'product' || 'other'])
                }
              })
            } else {
              setCurrentApiType('');
              setCurrentApiTypeName('')
            }
          }}
        />
        <ProFormText
          width="md"
          name="apiTypeName"
          placeholder={''}
          fieldProps={{ value: currentApiTypeName }}
          initialValue={currentApiTypeName}
          label="API类型"
          disabled
        />
      </ProForm.Group>
      <ProForm.Group >
        <ProFormText
          width="md"
          name="endpointCode"
          label="通道编码"
          placeholder="请输入通道编码"
          rules={[
            {
              required: true,
              message: '请输入通道编码',
            },
          ]}
        />

        <ProFormText
          width="md"
          name="endpointName"
          label="通道名称"
          placeholder="请输入通道名称"
          rules={[
            {
              required: true,
              message: '请输入通道名称',
            },
          ]}
        />
      </ProForm.Group>
      <ProFormSelect
        name="endpointType"
        label="通道类型"
        valueEnum={{
          customize: '自定义',
          configurable: '配置化',
        }}
        placeholder="请选择通道类型"
        rules={[
          {
            required: true,
            message: '请选择通道类型',
          },
        ]}
      />
      <ProForm.Group>
        <ProFormSelect
          width="md"
          name="integrateType"
          label="集成标准"
          valueEnum={{
            us: '我方标准',
            organization: '机构标准',
          }}
          placeholder="请选择集成标准"
          required
        />
        {
          currentApiType === 'loan' ? <ProFormSelect width="md" name="integrateSystem" label="集成系统"
            valueEnum={{
              1: '我方通用API',
              2: '合作方CRM',
              3: '三方CRM(ec)',
              4: '三方CRM(庆鱼)',
              5: '三方CRM(锦蝶)',
              6: '三方CRM(融享客)',
              7: '三方CRM(鑫鹿)',
              8: '三方CRM(庆鱼2.0)',
              9: '惠融易客CRM',
              10: '三方CRM(享客达)',
              11: '三方CRM(庆鱼3.0)',
              12: '三方CRM(锦蝶V3)',
              13: '我方通用AES模式',
            }}
            placeholder="请选择集成系统"
          /> : <div />
        }
      </ProForm.Group>
      <ProFormTextArea
        name="memo"
        label="备注"
        placeholder="请输入备注"
      />
      <ProFormText name='apiType' fieldProps={{ value: currentApiType }} initialValue={currentApiType}
        wrapperCol={{ style: { display: 'none' } }}
      />
    </StepsForm.StepForm>
  );
}
export default BasicInfoStepFormPage;