import React from 'react';
import { SearchOutlined } from '@ant-design/icons';
import { ProForm, ProFormSelect, ProFormText } from '@ant-design/pro-components';
import { Button, Col, Tabs } from 'antd';
import { TabsProps } from 'antd/lib';

import ApiHeader from './header';
import ApiQuery from './query';
import ApiPath from './path';
import ApiBody from './body';

/**
 * @author bianlanzhou
 * @since 2024-09-24
 * @desc HTTP配置
 */

class HttpClient extends React.Component {

  render() {
    const items: TabsProps['items'] = [
      {
        key: 'Header',
        label: 'Header',
        children: <ApiHeader />,
      },
      {
        key: 'Path',
        label: 'Path',
        children: <ApiPath />,
      },
      {
        key: 'Query',
        label: 'Query',
        children: <ApiQuery />,
      },
      {
        key: 'Body',
        label: 'Body',
        children: <ApiBody />,
      },
    ];
    return (
      <div style={{ width: '70vw' }}>
        <ProForm.Group >
          <ProFormSelect name="method" placeholder="请选择请求方法"
            valueEnum={{
              GET: 'GET',
              POST: 'POST',
              PUT: 'PUT',
              DELETE: 'DELETE',
            }}
            width={'sm'}
            rules={[
              {
                required: true,
                message: '请选择请求方法',
              },
            ]}
            colProps={{ span: 2 }}
          />
          <ProFormText colProps={{ span: 20 }} name="url" placeholder="输入请求地址" style={{ paddinglef: '10px' }} />
          <Col span={2} style={{ marginBottom: '-12px', marginTop: '-5px' }}>
            <Button type="primary" icon={<SearchOutlined />} >
              测试
            </Button>
          </Col>
          <Col span={24}>
            <Tabs defaultActiveKey="1" items={items} />
          </Col>
        </ProForm.Group>
      </div>
    )
  }
}
export default HttpClient;