import { FooterToolbar, PageContainer, ProCard, ProFormInstance, StepsForm } from '@ant-design/pro-components';
import React, { useRef, useState } from 'react';
import { history } from 'umi';
import BasicInfoStepFormPage from './component/BasicInfoStepFormPage';
import ConfigInfoStepFormPage from './component/ConfigInfoStepFormPage';
import { Button, Popconfirm } from 'antd';


/**
 * @author bianlanzhou
 * @since 2024-09-24
 * @desc 创建API通道页面
 */
const CreateApiChannelPage: React.FC = () => {
  /**基础信息form引用 */
  const basicInfoFormRef = useRef<ProFormInstance>();

  const [currentChannelType, setCurrentChannelType] = useState<string>('');

  return (
    <PageContainer
      header={{
        title: '',
      }}
    >
      <ProCard >
        <StepsForm
          formProps={
            {
              initialValues: {
                contentType: 'raw'
              }
            }
          }
          onCurrentChange={(current: number) => {
            if (current === 1) {
              setCurrentChannelType(basicInfoFormRef.current?.getFieldValue('channelType'))
            }
          }}
          onFinish={(values) => {
            const param = {
              basic: {
                apiId: values.apiId,
                channelCode: values.channelCode,
                channelName: values.channelName,
                channelType: values.channelType,
                integrateType: values.integrateType,
                memo: values.memo,
              },
              config: values.config,
              httpConfig: JSON.stringify(
                {
                  url: values.url,
                  path: values.path,
                  method: values.method,
                  query: values.query,
                  header: values.header,
                  contentType: values.contentType,
                  body: values.body,
                }
              )
            }
            console.log(param)
            return Promise.resolve(true);
          }}
          submitter={{
            render: (props) => {
              if (props.step === 0) {
                return (
                  <FooterToolbar >
                    <Popconfirm
                      title="确认返回列表页?"
                      okText="确定"
                      cancelText="取消"
                      onConfirm={() => {
                        history.push(
                          {
                            pathname: '/gateway/egress/api-channel',
                          },
                        )
                      }}
                    >
                      <Button>
                        返回列表页
                      </Button>
                    </Popconfirm>
                    <Button type="primary" onClick={() => props.onSubmit?.()}>
                      下一步
                    </Button>
                  </FooterToolbar>
                );
              }

              return (
                <FooterToolbar >
                  <Button key="gotoOne" onClick={() => props.onPre?.()}>
                    上一步
                  </Button>
                  <Popconfirm
                    title="确认提交表单?"
                    okText="确定"
                    cancelText="取消"
                    onConfirm={() => props.onSubmit?.()}
                  >
                    <Button
                      type="primary"
                      key="submit"
                    >
                      提交
                    </Button>
                  </Popconfirm>
                </FooterToolbar>
              );
            },
          }}
        >
          <BasicInfoStepFormPage formref={basicInfoFormRef} />
          <ConfigInfoStepFormPage configtype={currentChannelType} />
        </StepsForm>
      </ProCard>
    </PageContainer >
  );
}
export default CreateApiChannelPage;