import { ProTable } from '@ant-design/pro-components';
import { PageContainer } from '@ant-design/pro-layout';
import React, { useRef } from 'react';
import { history } from 'umi';

import { pageQueryEgressApiChannel } from '@/services/op-admin/gateway/egress';
import { PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { Button, Tag } from 'antd';
import CreateChannelFormModal from './component/CreateChannelModal';
/**
 * @author bianlanzhou
 * @since 2024-10-25
 * @desc 接出API通道列表
 */
const EgressApiChannelTable: React.FC = () => {
  /** 引用 */
  const actionRef = useRef<ActionType>();

  /** 列定义 */
  const columns: ProColumns<EGRESS.ApiChannelItem>[] = [
    {
      title: '序号',
      dataIndex: 'index',
      valueType: 'indexBorder',
      width: 48,
    },
    {
      title: '所属API名称',
      dataIndex: 'apiName',
    },
    {
      title: '通道名称',
      dataIndex: 'channelName',
    },
    {
      title: 'API类型',
      dataIndex: 'apiType',
      search: false,
      valueEnum: {
        loan: <Tag color="orange">助贷API</Tag>,
      },
    },
    {
      title: '创建时间',
      dataIndex: 'gmtCreate',
      search: false,
    },
    {
      title: '修改时间',
      dataIndex: 'gmtModify',
      search: false,
    },
    {
      title: '操作',
      valueType: 'option',
      width: '10%',
      render: (_, record) => [
        <a key="view" onClick={() => { }}>
          查看
        </a>,
        <a
          key="edit"
          onClick={() => {
            history.push(
              {
                pathname: '/ui/gateway/egress/loan-integration',
              },
              { id: record.apiId, from: '/ui/gateway/egress/channel' },
            );
          }}
        >
          编辑
        </a>,
      ],
    },
  ];
  return (
    <PageContainer
      header={{
        title: '',
      }}
    >
      <ProTable<EGRESS.ApiChannelItem>
        columns={columns}
        cardBordered
        actionRef={actionRef}
        request={pageQueryEgressApiChannel}
        editable={{
          type: 'multiple',
        }}
        rowKey="id"
        search={{
          labelWidth: 'auto',
        }}
        pagination={{
          pageSize: 10,
        }}
        toolBarRender={() => [
          <CreateChannelFormModal
            key="create"
            trigger={
              <Button key="create" type="primary" onClick={() => { }} icon={<PlusOutlined />}>
                创建API通道
              </Button>
            }
            callback={() => {
              actionRef.current?.reload();
            }}
          />,
        ]}
        headerTitle="通道列表"
      />
    </PageContainer>
  );
};
export default EgressApiChannelTable;
