import HttpClient from '@/components/HttpUtil';
import {
  loanApiIntegration,
  queryApiLoan,
  queryEgressApiChannel,
} from '@/services/op-admin/gateway/egress';
import { queryMerchant } from '@/services/op-admin/gateway/merchant';
import {
  FooterToolbar,
  PageContainer,
  ProCard,
  ProForm,
  ProFormInstance,
  ProFormSelect,
  ProFormTextArea,
  StepsForm,
} from '@ant-design/pro-components';
import { useLocation } from '@umijs/max';
import { history } from 'umi';
import { Button, message, Popconfirm, Spin } from 'antd';
import React, { useRef, useState } from 'react';

/**
 * @author bianlanzhou
 * @since 2024-10-24
 * @desc 助贷对接页面
 */
const LoanIntegration: React.FC = () => {
  /** mainForm引用 */
  const mainFormRef = useRef<ProFormInstance>();
  /** 跳转过来的location对象 */
  const location = useLocation();
  /** 撞库配置表单数据 */
  const [checkIntoFormData, setCheckIntoFormData] = useState<any>();
  /** 页面loading */
  const [pageLoading, setPageLoading] = useState<boolean>(false);
  /** 撞库通道集成方式 */
  const [ciChannelIntegrationMode, setCiChannelIntegrationMode] = useState('customize');
  /** 注册通道集成方式 */
  const [apyChannelIntegrationMode, setApyChannelIntegrationMode] = useState('customize');
  /** 撞库通道ID */
  const [checkintoChannelId, setCheckintoChannelId] = useState<string>('');
  /** 申请注册ID */
  const [applyChannelId, setApplyintoChannelId] = useState<string>('');
  /** 查询撞库通道 */
  const handleQueryCheckintoChannel = () => {
    return queryEgressApiChannel({
      channelCode: 'checkinto',
      apiId: (location.state as { id: string; from: string }).id,
    })
      .then((resp) => {
        if (resp.data && resp.data.length > 0) {
          let integrationMode = resp.data[0].integrationMode;
          setCiChannelIntegrationMode(integrationMode);
          setCheckintoChannelId(resp.data[0].id);
          if (integrationMode === 'guide') {
            return {
              ...resp.data[0],
              ...JSON.parse(resp.data[0].requestConfig),
            };
          } else {
            return {
              ...resp.data[0],
              ...resp.data[0].requestConfig,
            };
          }
        } else {
          //默认值
          setCiChannelIntegrationMode('customize');
          return {
            integrationMode: 'customize',
          };
        }
      })
      .catch();
  };

  /** 查询申请通道 */
  const handleQueryApplyChannel = () => {
    return queryEgressApiChannel({
      channelCode: 'apply',
      apiId: (location.state as { id: string; from: string }).id,
    })
      .then((resp) => {
        if (resp.data && resp.data.length > 0) {
          let integrationMode = resp.data[0].integrationMode;
          setApyChannelIntegrationMode(resp.data[0].integrationMode);
          setApplyintoChannelId(resp.data[0].id);
          if (integrationMode === 'guide') {
            return {
              ...resp.data[0],
              ...JSON.parse(resp.data[0].requestConfig),
            };
          } else {
            return {
              ...resp.data[0],
              ...resp.data[0].requestConfig,
            };
          }
        } else {
          setApyChannelIntegrationMode('customize');
          return {
            integrationMode: 'customize',
          };
        }
      })
      .catch();
  };

  /** 查询助贷API */
  const handleQueryApiLoan = () => {
    return queryApiLoan({ apiId: (location.state as { id: string; from: string }).id })
      .then((resp) => {
        if (resp.data) {
          return resp.data;
        }
        return {};
      })
      .catch();
  };

  /** 处理查询商户信息 */
  const handleQueryMerchant = () => {
    return queryMerchant()
      .then((resp) => {
        if (resp.success) {
          return resp.data;
        }
        message.error('查询商户信息失败!');
      })
      .catch((err) => {
        console.log(err);
      });
  };

  /** 处理撞库通道formData */
  const handleChannelFormData = (channelId: string, formData: any) => {
    const locationStateData = location.state as { id: string; from: string };
    let requestConfigStr = '';
    if (formData.integrationMode === 'guide') {
      const requestConfigJson = {
        url: formData.url,
        method: formData.method,
        header: formData.header,
        path: formData.path,
        query: formData.query,
        body: formData.body,
      };
      requestConfigStr = JSON.stringify(requestConfigJson);
    } else {
      requestConfigStr = formData.requestConfig;
    }
    return {
      id: channelId,
      apiId: locationStateData.id,
      integrationMode: formData.integrationMode,
      requestConfig: requestConfigStr,
      responseConfig: formData.responseConfig,
    };
  };


  return (
    <PageContainer
      header={{
        title: '',
      }}
    >
      <Spin spinning={pageLoading}>
        <ProForm
          formRef={mainFormRef}
          name="mainForm"
          submitter={{
            render: () => {
              return <div></div>;
            },
          }}
          request={handleQueryApiLoan}
        >
          <ProCard>
            <ProForm.Group>
              <ProFormSelect
                width="md"
                name="merchantId"
                label="商户名称"
                placeholder="请选择商户名称"
                request={handleQueryMerchant}
                fieldProps={{
                  fieldNames: {
                    label: 'merchantName',
                    value: 'id',
                  },
                }}
                required
              />
              <ProFormSelect
                width="md"
                name="integrationSystem"
                label="集成系统"
                valueEnum={{
                  1: '我方通用API',
                  2: '合作方CRM',
                  3: '三方CRM(ec)',
                  4: '三方CRM(庆鱼)',
                  5: '三方CRM(锦蝶)',
                  6: '三方CRM(融享客)',
                  7: '三方CRM(鑫鹿)',
                  8: '三方CRM(庆鱼2.0)',
                  9: '惠融易客CRM',
                  10: '三方CRM(享客达)',
                  11: '三方CRM(庆鱼3.0)',
                  12: '三方CRM(锦蝶V3)',
                  13: '我方通用AES模式',
                }}
                placeholder="请选择集成系统"
              />
              <ProFormSelect
                width="md"
                name="checkinto"
                label="是否撞库"
                valueEnum={{
                  yes: '是',
                  no: '否',
                }}
                placeholder="请选择是否撞库"
                rules={[
                  {
                    required: true,
                    message: '请选择是否撞库',
                  },
                ]}
              />
            </ProForm.Group>
          </ProCard>
        </ProForm>
        <ProCard style={{ marginTop: '10px' }}>
          <StepsForm
            formProps={{
              initialValues: {
                contentType: 'raw',
              },
            }}
            submitter={{
              render: (props) => {
                if (props.step === 0) {
                  return (
                    <FooterToolbar>
                      <Popconfirm
                        title="确认返回列表页?"
                        okText="确定"
                        cancelText="取消"
                        onConfirm={() => {
                          history.push({
                            pathname: (location.state as { id: string; from: string }).from,
                          });
                        }}
                      >
                        <Button>返回</Button>
                      </Popconfirm>
                      <Button type="primary" onClick={() => props.onSubmit?.()}>
                        下一步
                      </Button>
                    </FooterToolbar>
                  );
                }

                return (
                  <FooterToolbar>
                    <Button key="gotoOne" onClick={() => props.onPre?.()}>
                      上一步
                    </Button>
                    <Popconfirm
                      title="确认提交表单?"
                      okText="确定"
                      cancelText="取消"
                      onConfirm={() => props.onSubmit?.()}
                    >
                      <Button type="primary" key="submit">
                        提交
                      </Button>
                    </Popconfirm>
                  </FooterToolbar>
                );
              },
            }}
          >
            <StepsForm.StepForm
              name="checkInto"
              title="撞库"
              grid
              request={handleQueryCheckintoChannel}
              onFinish={async (formData) => {
                let checkintoFormData = handleChannelFormData(checkintoChannelId, formData);
                setCheckIntoFormData(checkintoFormData);
                return true;
              }}
            >
              <ProCard title="通道配置" bordered>
                <ProFormSelect<string>
                  name="integrationMode"
                  placeholder="请选择配置方式"
                  valueEnum={{
                    customize: '自定义代码方式',
                    guide: '向导配置方式',
                  }}
                  label="集成方式"
                  width="sm"
                  rules={[
                    {
                      required: true,
                      message: '请选择集成方式',
                    },
                  ]}
                  onChange={(value) => {
                    setCiChannelIntegrationMode(value);
                  }}
                />
              </ProCard>
              <ProCard title="请求配置" bordered style={{ marginTop: '5px' }}>
                {ciChannelIntegrationMode === 'customize' ? (
                  <div style={{ width: '85vw' }}>
                    <ProFormTextArea
                      label="请求配置参数"
                      rules={[
                        {
                          required: true,
                          message: '请填写请求配置参数',
                        },
                      ]}
                      name="requestConfig"
                      fieldProps={{
                        rows: 8,
                      }}
                    />
                  </div>
                ) : (
                  <HttpClient />
                )}
              </ProCard>
              {ciChannelIntegrationMode === 'customize' ? (
                <div />
              ) : (
                <ProCard title="响应配置" bordered style={{ marginTop: '5px' }}>
                  <div style={{ width: '85vw' }}>
                    <ProFormTextArea
                      label="响应配置参数"
                      rules={[
                        {
                          required: true,
                          message: '请填写响应配置参数',
                        },
                      ]}
                      name="responseConfig"
                      fieldProps={{
                        rows: 8,
                      }}
                    />
                  </div>
                </ProCard>
              )}
            </StepsForm.StepForm>

            {/* 分界线 */}

            <StepsForm.StepForm
              name="apply"
              title="注册"
              wrapperCol={{ span: 24 }}
              request={handleQueryApplyChannel}
              grid
              onFinish={async (formData) => {
                setPageLoading(true);
                let locationStateData = location.state as { id: string; from: string };
                let applyFormData = handleChannelFormData(applyChannelId, formData);
                loanApiIntegration({
                  apiId: locationStateData.id,
                  apiLoanInfo: mainFormRef.current?.getFieldFormatValueObject?.() as ApiLoan,
                  checkinto: checkIntoFormData,
                  apply: applyFormData,
                })
                  .then((resp) => {
                    if (resp.success) {
                      let toPathname = '/ui/gateway/egress/channel';
                      if (locationStateData.from === 'api') {
                        toPathname = '/ui/gateway/egress/api';
                      }
                      message.success('操作成功!');
                      history.push({
                        pathname: toPathname,
                      });
                    }
                  })
                  .catch((err) => {
                    setPageLoading(false);
                    console.log(err);
                  });
                return false;
              }}
            >
              <ProCard title="通道配置" bordered>
                <ProFormSelect<string>
                  name="integrationMode"
                  placeholder="请选择配置方式"
                  valueEnum={{
                    customize: '自定义代码方式',
                    guide: '向导配置方式',
                  }}
                  label="集成方式"
                  width="sm"
                  rules={[
                    {
                      required: true,
                      message: '请选择集成方式',
                    },
                  ]}
                  onChange={(value) => {
                    setApyChannelIntegrationMode(value);
                  }}
                />
              </ProCard>
              <ProCard title="请求配置" bordered style={{ marginTop: '5px' }}>
                {apyChannelIntegrationMode === 'customize' ? (
                  <div style={{ width: '85vw' }}>
                    <ProFormTextArea
                      label="请求配置参数"
                      rules={[
                        {
                          required: true,
                          message: '请填写请求配置参数',
                        },
                      ]}
                      name="requestConfig"
                      fieldProps={{
                        rows: 8,
                      }}
                    />
                  </div>
                ) : (
                  <HttpClient />
                )}
              </ProCard>
              {ciChannelIntegrationMode === 'customize' ? (
                <div />
              ) : (
                <ProCard title="响应配置" bordered style={{ marginTop: '5px' }}>
                  <div style={{ width: '85vw' }}>
                    <ProFormTextArea
                      label="响应配置参数"
                      rules={[
                        {
                          required: true,
                          message: '请填写响应配置参数',
                        },
                      ]}
                      name="responseConfig"
                      fieldProps={{
                        rows: 8,
                      }}
                    />
                  </div>
                </ProCard>
              )}
            </StepsForm.StepForm>
          </StepsForm>
        </ProCard>
      </Spin>
    </PageContainer>
  );
};
export default LoanIntegration;
