import { queryEgressApi, queryEgressApiChannel } from '@/services/op-admin/gateway/egress';
import { querySmsPlatform, upsertSmsChannel } from '@/services/op-admin/message/sms';
import { ModalForm, ProForm, ProFormSelect, ProFormText } from '@ant-design/pro-components';
import { message } from 'antd';
import React, { useState } from 'react';

/**
 * @author bianlanzhou
 * @since 2024-11-07
 * @desc 
 */
const UpsertSmsChannelModalForm: React.FC<UpsertSmsChannelModalFormProp> = (props) => {
  const [form] = ProForm.useForm();

  /** API通道列表 */
  const [apiChannelOption, setApiChannelOption] = useState([]);

  /** 提交方法 */
  const handleSubmit = (value: SMS.ChannelUpsertCmd) => {
    if (props.data) {
      value.id = props.data.id;
    }
    return upsertSmsChannel(value).then(() => {
      message.success("操作成功!")
      props.callback();
      return true;
    }).catch((err) => {
      console.log(err)
      return false;
    });
  }
  return (
    <ModalForm<SMS.ChannelUpsertCmd>
      trigger={props.trigger}
      title="短信通道"
      onFinish={handleSubmit}
      clearOnDestroy={true}
      initialValues={
        props.data
      }
      form={form}
    >
      <ProForm.Group>
        <ProFormText
          width="md"
          name="channelName"
          label="平台名称"
          rules={[
            {
              required: true,
              message: '请填写平台名称',
            },
          ]}
          placeholder="请填写平台名称"
          required
        />
        <ProFormSelect name="platformId" placeholder="请选择短信平台"
          label='绑定短信平台'
          width='md'
          rules={[
            {
              required: true,
              message: '请选择短信平台',
            },
          ]}
          fieldProps={
            {
              fieldNames: {
                label: 'platformName',
                value: 'id'
              }
            }
          }
          request={() => {
            return querySmsPlatform().then((resp) => {
              return resp.data
            })
          }}
        />
        <ProFormSelect name="apiId" placeholder="请选择短信API"
          label='绑定短信API'
          width='md'
          rules={[
            {
              required: true,
              message: '请选择短信API',
            },
          ]}
          fieldProps={
            {
              fieldNames: {
                label: 'apiName',
                value: 'id'
              }
            }
          }
          request={() => {
            return queryEgressApi({ apiType: 'sms' }).then((resp) => {
              return resp.data;
            })
          }}
          onChange={(value) => {
            queryEgressApiChannel({ apiId: value }).then((resp) => {
              setApiChannelOption(resp.data.map((item: any) => {
                return {
                  value: item.id, label: item.channelName
                };
              }))
            })
          }}
        />
        <ProFormSelect name="apiChannelId" placeholder="请选择短信API通道"
          label='绑定短信API通道'
          width='md'
          options={apiChannelOption}
          rules={[
            {
              required: true,
              message: '请选择短信API通道',
            },
          ]}
        />
      </ProForm.Group>
    </ModalForm>
  );
}
export default UpsertSmsChannelModalForm;