import { querySmsChannel, querySmsPlatform, querySmsSign, querySmsTemplate, upsertSmsService } from '@/services/op-admin/message/sms';
import { ModalForm, ProFormSelect, ProFormText } from '@ant-design/pro-components';
import { Card, Col, message } from 'antd';
import { Row } from 'antd/lib';
import React, { useState } from 'react';
/**
 * @author bianlanzhou
 * @since 2024-11-06
 * @desc 创建/更新短信服务
 */
const UpsertSmsServiceModalForm: React.FC<UpsertSmsServiceModalFormProp> = (props) => {

  /** 短信通道列表 */
  const [smsChannelOption, setSmsChannelOption] = useState([]);

  /** 提交方法 */
  const handleSubmit = (value: SMS.ServiceUpsertCmd) => {
    if (props.data) {
      value.id = props.data.id;
    }
    return upsertSmsService(value).then(() => {
      message.success("操作成功!")
      props.callback();
      return true;
    }).catch((err) => {
      console.log(err)
      return false;
    });
  }

  return (
    <ModalForm<SMS.ServiceUpsertCmd>
      trigger={props.trigger}
      title="短信服务"
      onFinish={handleSubmit}
      initialValues={
        props.data
      }
    >
      <Row gutter={[16, 16]}>
        <Col span={12} >
          <ProFormText
            width="md"
            name="serviceName"
            label="服务名称"
            rules={[
              {
                required: true,
                message: '请填写服务名称',
              },
            ]}
            placeholder="请填写服务名称"
            required
          />
          <ProFormText
            width="md"
            name="serviceCode"
            label="服务编码"
            rules={[
              {
                required: true,
                message: '请填写服务编码',
              },
            ]}
            placeholder="请填写服务编码"
            required
          />
          <ProFormSelect name="smsPlatformId" placeholder="请选择短信平台"
            label='短信平台'
            width='md'
            rules={[
              {
                required: true,
                message: '请选择短信平台',
              },
            ]}
            fieldProps={{
              fieldNames: {
                label: 'platformName',
                value: 'id',
              },
            }}
            request={() => {
              return querySmsPlatform().then((resp) => {
                return resp.data;
              })
            }}
            onChange={(value) => {
              querySmsChannel({ platformId: value }).then((resp) => {
                setSmsChannelOption(resp.data)
              });
            }}
          />
          <ProFormSelect name="smsChannelId" placeholder="请选择短信通道"
            label='短信通道'
            width='md'
            options={smsChannelOption}
            rules={[
              {
                required: true,
                message: '请选择短信通道',
              },
            ]}
          />
          <ProFormSelect name="signId" placeholder="请选择短信签名"
            label='短信签名'
            width='md'
            rules={[
              {
                required: true,
                message: '请选择短信签名',
              },
            ]}
            fieldProps={{
              fieldNames: {
                label: 'signatureName',
                value: 'id',
              },
            }}
            request={() => {
              return querySmsSign().then((resp) => {
                return resp.data;
              })
            }}
          />
          <ProFormSelect name="templateId" placeholder="请选择短信模版"
            label='短信模版'
            width='md'
            rules={[
              {
                required: true,
                message: '请选择短信模版',
              },
            ]}
            fieldProps={{
              fieldNames: {
                label: 'templateName',
                value: 'id',
              },
            }}
            request={() => {
              return querySmsTemplate().then((resp) => {
                return resp.data;
              })
            }}
          />
        </Col>
        <Col span={12} >
          <Card title="短信预览" style={{ height: '100%' }} >
            <Card title={false} style={{ borderTopLeftRadius: '0 0', borderTopRightRadius: '5px 10px', borderBottomLeftRadius: '5px 10px', borderBottomRightRadius: '5px 10px', minHeight: '30px', fontSize: '15px' }}>
              { }
            </Card>
          </Card>
        </Col>
      </Row>

    </ModalForm >
  );
}

export default UpsertSmsServiceModalForm;